@@ -28,9 +28,11 @@
 #include "ui_mainwindow.h"
 #include "flattabwidget.h"
 
+#include <avogadro/primitivelist.h>
+#include <avogadro/extension.h>
+
 #include <QMainWindow>
 #include <QFileDialog>
-#include <avogadro/primitivelist.h>
 #include <QTabWidget>
 
 class QUndoStack;
@@ -128,6 +130,7 @@ namespace Avogadro {
       void centerView();
       void setView(int index);
       void fullScreen();
+      void resetDisplayTypes();
       void showSettingsDialog();
       void setBackgroundColor();
       void setPainterQuality(int quality);
@@ -174,16 +177,11 @@ namespace Avogadro {
        */
       void addActionsToMenu(Extension *extension);
 
-      /**
-       * @param molecule set the current molecule and take ownership
-       */
-      void setMolecule(Molecule *molecule);
-
       /**
        * @param molecule set the current molecule and take ownership
        * @param options Enum found in Extension with options for new Molecule
        */
-      void setMolecule(Molecule *molecule, int options);
+      void setMolecule(Molecule *molecule, int options = Extension::DeleteOld);
 
       /**
        * Slot to check we have the correct active GLWidget.
@@ -220,6 +218,9 @@ namespace Avogadro {
       void setFileName(const QString &fileName);
       void updateRecentFileActions();
 
+      bool isDefaultFileName(const QString fileName);
+      QString defaultFileName();
+
       /***
        * Function for creating new GLWidgets
        * \return a pointer to a new GLWidget which has been added to the
