@@ -643,9 +643,9 @@ namespace Avogadro {
       return d->colorMap;
     }
     else {
-      if(!d->defaultColorMap)
-      {
-        d->defaultColorMap = static_cast<Color*>(PluginManager::factories(Plugin::ColorType).at(0)->createInstance());
+      if(!d->defaultColorMap) {
+        PluginManager *plugins = PluginManager::instance();
+        d->defaultColorMap = static_cast<Color*>(plugins->factories(Plugin::ColorType).at(0)->createInstance());
       }
       return d->defaultColorMap;
     }
@@ -701,6 +701,11 @@ namespace Avogadro {
       qDebug() << "GLWidget::render(): No molecule set.";
       return;
     }
+    if (!d->molecule->lock()->tryLockForRead()) {
+      qDebug() << "GLWidget::render(): Could not get read lock on molecule.";
+      return;
+    }
+
     d->painter->begin(this);
 
     if (d->painter->quality() >= 3) {
@@ -807,6 +812,7 @@ namespace Avogadro {
     if (d->renderDebug) renderDebugOverlay();
 
     d->painter->end();
+    d->molecule->lock()->unlock();
   }
 
   void GLWidget::renderCrystal(GLuint displayList)
@@ -1006,13 +1012,13 @@ namespace Avogadro {
     y += d->pd->painter()->drawText(x, y, "---- " + tr("Debug Information") + " ----");
     y += d->pd->painter()->drawText(x, y, tr("FPS: %L1").arg(computeFramesPerSecond(), 0, 'g', 3));
 
-    y += d->pd->painter()->drawText(x, y, 
+    y += d->pd->painter()->drawText(x, y,
                                     tr("View Size: %L1 x %L2").arg(d->pd->width()).arg(d->pd->height()) );
     if (!d->molecule) {
       y += d->pd->painter()->drawText(x, y, tr("No molecule set"));
       return;
     }
- 
+
 //    list = primitives().subList(Primitive::AtomType);
     y += d->pd->painter()->drawText(x, y, tr("Atoms: %L1").arg(d->molecule->numAtoms()));
 
@@ -1182,12 +1188,16 @@ namespace Avogadro {
     // When the molecule is updated, the display lists become invalid, we should
     // also render the updated molecule. This should be much simpler than before.
     connect(d->molecule, SIGNAL(updated()), this, SLOT(invalidateDLs()));
+    connect(d->molecule, SIGNAL(updated()), this, SLOT(updateGeometry()));
     connect(d->molecule, SIGNAL(updated()), this, SLOT(update()));
 
     // If primitives, atoms, or bonds are removed, we need to delete them from the selected list
-    connect(d->molecule, SIGNAL(primitiveRemoved(Primitive*)), this, SLOT(unselectPrimitive(Primitive*)));
-    connect(d->molecule, SIGNAL(atomRemoved(Atom*)), this, SLOT(unselectAtom(Atom*)));
-    connect(d->molecule, SIGNAL(bondRemoved(Bond*)), this, SLOT(unselectBond(Bond*)));
+    connect(d->molecule, SIGNAL(primitiveRemoved(Primitive*)),
+            this, SLOT(unselectPrimitive(Primitive*)));
+    connect(d->molecule, SIGNAL(atomRemoved(Atom*)),
+            this, SLOT(unselectAtom(Atom*)));
+    connect(d->molecule, SIGNAL(bondRemoved(Bond*)),
+            this, SLOT(unselectBond(Bond*)));
 
     // setup the camera to have a nice viewpoint on the molecule
     d->camera->initializeViewPoint();
@@ -1246,61 +1256,66 @@ namespace Avogadro {
 
   void GLWidget::updateGeometry()
   {
-    if (!d->molecule) return;
- 
-    if ( d->molecule->OBUnitCell() == NULL ) {
-      //plain molecule, no crystal cell
+    if (!d->molecule)
+      return;
+
+    // Try to get a read lock for the molecule
+    if (!d->molecule->lock()->tryLockForRead())
+      return;
+
+    if (!d->molecule->OBUnitCell()) {
+      // Plain molecule, no crystal cell
       d->center = d->molecule->center();
       d->normalVector = d->molecule->normalVector();
       d->radius = d->molecule->radius();
       d->farthestAtom = d->molecule->farthestAtom();
-      return;
     }
-
-    // render a crystal (so most geometry comes from the cell vectors)
-    // Origin at 0.0, 0.0, 0.0
-    // a = <x0, y0, z0>
-    // b = <x1, y1, z1>
-    // c = <x2, y2, z2>
-    std::vector<vector3> cellVectors = d->molecule->OBUnitCell()->GetCellVectors();
-    Vector3d a(cellVectors[0].AsArray());
-    Vector3d b(cellVectors[1].AsArray());
-    Vector3d c(cellVectors[2].AsArray());
-    Vector3d centerOffset = ( a * (d->aCells - 1)
-                  + b * (d->bCells - 1)
-                  + c * (d->cCells - 1) ) / 2.0;
-    // the center is the center of the molecule translated by centerOffset
-    d->center = d->molecule->center() + centerOffset;
-    // the radius is the length of centerOffset plus the molecule radius
-    d->radius = d->molecule->radius() + centerOffset.norm();
-    // for the normal vector, we just ask for the molecule's normal vector,
-    // crossing our fingers hoping that it will give a nice viewpoint not only
-    // with respect to the molecule but also with respect to the cells.
-    d->normalVector = d->molecule->normalVector();
-    // Computation of the farthest atom.
-    // First case: the molecule is empty
-    if(d->molecule->numAtoms() == 0)
-      d->farthestAtom = 0;
-    // Second case: there is no repetition of the molecule
-    else if(d->aCells <= 1 && d->bCells <= 1 && d->cCells <= 1)
-      d->farthestAtom = d->molecule->farthestAtom();
-    // General case: the farthest atom is the one that is located the
-    // farthest in the direction pointed to by centerOffset.
     else {
-      QList<Atom *> atoms = d->molecule->atoms();
-      double x, max_x;
-      // We don't need tis conditional, we tested for atoms above
-      //      if (atoms.size()) {
-      d->farthestAtom = atoms.at(0);
-      max_x = centerOffset.dot(*d->farthestAtom->pos());
-      foreach (Atom *atom, atoms) {
-        x = centerOffset.dot(*atom->pos());
-        if (x > max_x) {
-          max_x = x;
-          d->farthestAtom = atom;
-        }
-      } // end foreach
-    } // end general repeat (many atoms, multiple cells)
+      // render a crystal (so most geometry comes from the cell vectors)
+      // Origin at 0.0, 0.0, 0.0
+      // a = <x0, y0, z0>
+      // b = <x1, y1, z1>
+      // c = <x2, y2, z2>
+      std::vector<vector3> cellVectors = d->molecule->OBUnitCell()->GetCellVectors();
+      Vector3d a(cellVectors[0].AsArray());
+      Vector3d b(cellVectors[1].AsArray());
+      Vector3d c(cellVectors[2].AsArray());
+      Vector3d centerOffset = ( a * (d->aCells - 1)
+                              + b * (d->bCells - 1)
+                              + c * (d->cCells - 1) ) / 2.0;
+      // the center is the center of the molecule translated by centerOffset
+      d->center = d->molecule->center() + centerOffset;
+      // the radius is the length of centerOffset plus the molecule radius
+      d->radius = d->molecule->radius() + centerOffset.norm();
+      // for the normal vector, we just ask for the molecule's normal vector,
+      // crossing our fingers hoping that it will give a nice viewpoint not only
+      // with respect to the molecule but also with respect to the cells.
+      d->normalVector = d->molecule->normalVector();
+      // Computation of the farthest atom.
+      // First case: the molecule is empty
+      if(d->molecule->numAtoms() == 0)
+      d->farthestAtom = 0;
+      // Second case: there is no repetition of the molecule
+      else if(d->aCells <= 1 && d->bCells <= 1 && d->cCells <= 1)
+        d->farthestAtom = d->molecule->farthestAtom();
+      // General case: the farthest atom is the one that is located the
+      // farthest in the direction pointed to by centerOffset.
+      else {
+        QList<Atom *> atoms = d->molecule->atoms();
+        double x, max_x;
+
+        d->farthestAtom = atoms.at(0);
+        max_x = centerOffset.dot(*d->farthestAtom->pos());
+        foreach (Atom *atom, atoms) {
+          x = centerOffset.dot(*atom->pos());
+          if (x > max_x) {
+            max_x = x;
+            d->farthestAtom = atom;
+          }
+        } // end foreach
+      } // end general repeat (many atoms, multiple cells)
+    } // End the case for unit cells
+    d->molecule->lock()->unlock();
   }
 
   Camera * GLWidget::camera() const
@@ -1731,9 +1746,7 @@ namespace Avogadro {
   PrimitiveList GLWidget::namedSelectionPrimitives(int index)
   {
     PrimitiveList list;
-    if (!d->molecule) return list;
-
-    if (!d->molecule) 
+    if (!d->molecule)
       return list;
 
     for (int j = 0; j < d->namedSelections.at(index).second.first.size(); ++j) {
@@ -1826,6 +1839,8 @@ namespace Avogadro {
 
     int count = d->engines.size();
     settings.beginWriteArray("engines");
+    // Clear the array before writing settings - fixes issue when index changes
+    settings.remove("");
     for(int i = 0; i< count; i++) {
       settings.setArrayIndex(i);
       d->engines.at(i)->writeSettings(settings);
@@ -1842,14 +1857,15 @@ namespace Avogadro {
     d->renderAxes = settings.value("renderAxes", 1).value<bool>();
     d->renderDebug = settings.value("renderDebug", 0).value<bool>();
     d->allowQuickRender = settings.value("allowQuickRender", 1).value<bool>();
-    d->allowQuickRender = settings.value("renderUnitCellAxes", 1).value<bool>();
+    d->renderUnitCellAxes = settings.value("renderUnitCellAxes", 1).value<bool>();
 
     int count = settings.beginReadArray("engines");
     for(int i=0; i<count; i++) {
       settings.setArrayIndex(i);
       QString engineClass = settings.value("engineID", QString()).toString();
-      PluginFactory *factory = PluginManager::factory(engineClass,
-                                                      Plugin::EngineType);
+      PluginManager *plugins = PluginManager::instance();
+      PluginFactory *factory = plugins->factory(engineClass,
+                                                Plugin::EngineType);
       if(!engineClass.isEmpty() && factory) {
         Engine *engine = static_cast<Engine *>(factory->createInstance(this));
         engine->readSettings(settings);
@@ -1867,11 +1883,10 @@ namespace Avogadro {
     QList<Engine *> engines = d->engines;
 
     foreach(Engine *engine, engines)
-      delete engine;
+      this->removeEngine(engine);
 
-    d->engines.clear();
-
-    foreach(PluginFactory *factory, PluginManager::factories(Plugin::EngineType)) {
+    PluginManager *plugins = PluginManager::instance();
+    foreach(PluginFactory *factory, plugins->factories(Plugin::EngineType)) {
       Engine *engine = static_cast<Engine *>(factory->createInstance(this));
       if (engine->name() == tr("Ball and Stick"))
         engine->setEnabled(true);
@@ -1891,7 +1906,7 @@ namespace Avogadro {
       d->engines.at(i)->writeSettings(settings);
     }
     settings.endArray();
- 
+
     // delete engines
     foreach(Engine *engine, d->engines) {
       delete engine;
@@ -1905,8 +1920,9 @@ namespace Avogadro {
     for(int i=0; i<count; i++) {
       settings.setArrayIndex(i);
       QString engineClass = settings.value("engineID", QString()).toString();
-      PluginFactory *factory = PluginManager::factory(engineClass,
-                                                      Plugin::EngineType);
+      PluginManager *plugins = PluginManager::instance();
+      PluginFactory *factory = plugins->factory(engineClass,
+                                                Plugin::EngineType);
       if(!engineClass.isEmpty() && factory) {
         Engine *engine = static_cast<Engine *>(factory->createInstance(this));
         engine->readSettings(settings);
@@ -1916,7 +1932,7 @@ namespace Avogadro {
     settings.endArray();
   }
 
- 
+
   void GLWidget::setQuickRender(bool enabled)
   {
     d->allowQuickRender = enabled;
